read.sas7bdat: SAS Database Reader (experimental)
Description
Read SAS files in the sas7bdat data format.Arguments
file
Path to a file or an URL.
Value
- A data frame corresponding to the SAS database. The returned data frame has an
column.info attribute, which contains additional information about each field in the data frame, respectively. The column.info attribute is a list of lists, containing each of the following: - nameThe field name
- offsetThe field offset in packed binary row data (bytes)
- lengthThe field length (bytes)
- typeThe field type, either 'character' or 'numeric'
- When the database specifies a field format and/or label, the following may also be present:
- formatThe field display format
- labelThe field label (usually a longer description)
Warning
The functionality in this package is EXPERIMENTAL. Use at your own risk. For the latest details, see the sas7bdat vignette (i.e., vignette('sas7bdat')).References
http://biostatmatt.com/archives/tag/sas7bdatExamples
Run this code# read.sas7bdat("http://bus.utk.edu/stat/stat579/hotel.sas7bdat")
Run the code above in your browser using DataLab